import { IContainer } from '@ts-ioc/core';
import { AppConfigure } from './AppConfigure';
import { IApplicationBuilder } from './IApplicationBuilder';
import { IEvents } from '../utils';
import { RunnableBuilder, RunnableEvents } from './RunnableBuilder';
/**
 * application events
 *
 * @export
 * @enum {number}
 */
export declare const AppEvents: typeof RunnableEvents;
/**
 * application events
 */
export declare const ApplicationEvents: typeof RunnableEvents;
/**
 * application builder.
 *
 * @export
 * @class Default ApplicationBuilder
 * @extends {ModuleBuilder}
 * @template T
 */
export declare class ApplicationBuilder<T> extends RunnableBuilder<T> implements IApplicationBuilder<T>, IEvents {
    protected configs: (string | AppConfigure)[];
    constructor(baseURL?: string);
    /**
     * use configuration.
     *
     * @param {(string | AppConfigure)} [config]
     * @returns {this} global config for this application.
     * @memberof Bootstrap
     */
    useConfiguration(config?: string | AppConfigure): this;
    protected createConfigureMgr(): import("packages/bootstrap/src/boot/IConfigureManager").IConfigureManager<import("packages/bootstrap/src/modules/ModuleConfigure").ModuleConfigure>;
    /**
     * register by configure.
     *
     * @protected
     * @param {IContainer} container
     * @param {AppConfigure} config
     * @returns {Promise<void>}
     * @memberof RunnableBuilder
     */
    protected registerByConfigure(container: IContainer, config: AppConfigure): Promise<void>;
    static classAnnations: any;
}
